@@ -240,8 +240,28 @@ grn_ctx_impl_init(grn_ctx *ctx)
   }
   ctx->impl->db = NULL;
 
-  ctx->impl->expr_vars = grn_hash_create(ctx, NULL, sizeof(grn_id), sizeof(grn_obj *), 0);
+  if (!(ctx->impl->expr_vars = grn_hash_create(ctx, NULL, sizeof(grn_id),
+                                               sizeof(grn_obj *), 0))) {
+    grn_array_close(ctx, ctx->impl->values);
+    grn_pat_close(ctx, ctx->impl->temporary_columns);
+    CRITICAL_SECTION_FIN(ctx->impl->lock);
+    grn_io_anon_unmap(ctx, &mi, IMPL_SIZE);
+    grn_hash_close(ctx, ctx->impl->ios);
+    ctx->impl = NULL;
+    return ctx->rc;
+  }
+  if (!(ctx->impl->stack = GRN_MALLOCN(grn_obj *, GRN_STACK_SIZE))) {
+    grn_array_close(ctx, ctx->impl->values);
+    grn_pat_close(ctx, ctx->impl->temporary_columns);
+    CRITICAL_SECTION_FIN(ctx->impl->lock);
+    grn_io_anon_unmap(ctx, &mi, IMPL_SIZE);
+    grn_hash_close(ctx, ctx->impl->ios);
+    grn_hash_close(ctx, ctx->impl->expr_vars);
+    ctx->impl = NULL;
+    return ctx->rc;
+  }
   ctx->impl->stack_curr = 0;
+  ctx->impl->stack_size = GRN_STACK_SIZE;
   ctx->impl->curr_expr = NULL;
   GRN_TEXT_INIT(&ctx->impl->current_request_id, 0);
   ctx->impl->current_request_timer_id = NULL;
@@ -483,7 +503,7 @@ grn_ctx_fin(grn_ctx *ctx)
     GRN_OBJ_FIN(ctx, &ctx->impl->output.names);
     GRN_OBJ_FIN(ctx, &ctx->impl->output.levels);
     rc = grn_obj_close(ctx, ctx->impl->output.buf);
-    {
+    if (ctx->impl->expr_vars) {
       grn_hash **vp;
       grn_obj *value;
       GRN_HASH_EACH(ctx, ctx->impl->expr_vars, eid, NULL, NULL, &vp, {
@@ -494,8 +514,11 @@ grn_ctx_fin(grn_ctx *ctx)
         }
         grn_hash_close(ctx, *vp);
       });
+      grn_hash_close(ctx, ctx->impl->expr_vars);
+    }
+    if (ctx->impl->stack) {
+      GRN_FREE(ctx->impl->stack);
     }
-    grn_hash_close(ctx, ctx->impl->expr_vars);
     if (ctx->impl->db && ctx->flags & GRN_CTX_PER_DB) {
       grn_obj *db = ctx->impl->db;
       ctx->impl->db = NULL;
@@ -1041,7 +1064,7 @@ get_command_version(grn_ctx *ctx, const char *p, const char *pe)
 #define HTTP_QUERY_PAIR_DELIMITER   "="
 #define HTTP_QUERY_PAIRS_DELIMITERS "&;"
 
-static inline int
+static grn_inline int
 command_proc_p(grn_obj *expr)
 {
   return (expr->header.type == GRN_PROC &&
