@@ -40,6 +40,8 @@ typedef enum {
 typedef struct _grn_scan_info scan_info;
 typedef grn_bool (*grn_scan_info_each_arg_callback)(grn_ctx *ctx, grn_obj *obj, void *user_data);
 
+void grn_expr_init_from_env(void);
+
 scan_info **grn_scan_info_build(grn_ctx *ctx, grn_obj *expr, int *n,
                                 grn_operator op, grn_bool record_exist);
 
@@ -64,7 +66,7 @@ int grn_scan_info_get_max_interval(scan_info *si);
 void grn_scan_info_set_max_interval(scan_info *si, int max_interval);
 int grn_scan_info_get_similarity_threshold(scan_info *si);
 void grn_scan_info_set_similarity_threshold(scan_info *si, int similarity_threshold);
-grn_bool grn_scan_info_push_arg(scan_info *si, grn_obj *arg);
+grn_bool grn_scan_info_push_arg(grn_ctx *ctx, scan_info *si, grn_obj *arg);
 grn_obj *grn_scan_info_get_arg(grn_ctx *ctx, scan_info *si, int i);
 int grn_scan_info_get_start_position(scan_info *si);
 void grn_scan_info_set_start_position(scan_info *si, int start);
